@@ -10,7 +10,7 @@ use App::orgadb::Common;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-10-15'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our %SPEC;
 
@@ -478,7 +478,7 @@ App::orgadb - An opinionated Org addressbook toolset
 
 =head1 VERSION
 
-This document describes version 0.011 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-15.
+This document describes version 0.012 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-15.
 
 =head1 SYNOPSIS
 
@@ -529,6 +529,8 @@ Whether to use color.
 
 =item * B<color_theme> => I<perl::colortheme::modname_with_optional_args>
 
+(No description)
+
 =item * B<count> => I<true>
 
 Return just the number of matching entries instead of showing them.
@@ -560,7 +562,7 @@ file in IOD syntax, as rows of JSON hashes):
  ; but if 'hide_field_name' field is not set, normalize phone numbers using
  ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
  ; 5678').
- default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+ default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
 
 Condition keys:
 
@@ -586,6 +588,8 @@ specifying formatter.
 
 =item * B<detail> => I<bool>
 
+(No description)
+
 =item * B<entry> => I<str_or_re>
 
 Find entry by string or regex search against its title.
@@ -633,8 +637,8 @@ If formatter name begins with C<[> character, it will be parsed as JSON. Example
 
  ['Str::remove_comment', {'style':'cpp'}]
 
-Note that this option verrides C<--default-formatter-rules> but overridden by the
-C<--no-formatters> (C<--raw-field-values>, C<-F>) option.
+Note that this option overrides C<--default-formatter-rules> but is overridden by
+the C<--no-formatters> (C<--raw-field-values>, C<-F>) option.
 
 =item * B<hide_category> => I<true>
 
@@ -665,8 +669,12 @@ Specify maximum number of fields (per entry) to return (0 means unlimited).
 
 =item * B<reload_files_on_change> => I<bool> (default: 1)
 
+(No description)
+
 =item * B<shell> => I<true>
 
+(No description)
+
 
 =back
 
