@@ -8,7 +8,7 @@ use Log::ger;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-10-15'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 sub _heading_from_line {
     my $heading = shift;
@@ -362,7 +362,7 @@ file in IOD syntax, as rows of JSON hashes):
     ; but if 'hide_field_name' field is not set, normalize phone numbers using
     ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
     ; 5678').
-    default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+    default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
 
 Condition keys:
 
@@ -413,8 +413,8 @@ If formatter name begins with `[` character, it will be parsed as JSON. Example:
 
  ['Str::remove_comment', {'style':'cpp'}]
 
-Note that this option verrides `--default-formatter-rules` but overridden by the
-`--no-formatters` (`--raw-field-values`, `-F`) option.
+Note that this option overrides `--default-formatter-rules` but is overridden by
+the `--no-formatters` (`--raw-field-values`, `-F`) option.
 
 _
     },
@@ -464,7 +464,7 @@ App::orgadb::Common
 
 =head1 VERSION
 
-This document describes version 0.011 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-10-15.
+This document describes version 0.012 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-10-15.
 
 =head1 HOMEPAGE
 
